Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: ash/common/system/tray/system_tray.h

Issue 2190773002: Fix Volume slider is captured in screenshot done in touchview mode (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: based on new cr from Daniel Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/tray/system_tray.h
diff --git a/ash/common/system/tray/system_tray.h b/ash/common/system/tray/system_tray.h
index 9029cb16f70f1bdc8e728bd069cfb97fd7b382cf..35d9b9f6b24bc081ebb1541745d48fc49ed1d277 100644
--- a/ash/common/system/tray/system_tray.h
+++ b/ash/common/system/tray/system_tray.h
@@ -74,8 +74,9 @@ class ASH_EXPORT SystemTray : public TrayBackgroundView,
// seconds.
void SetDetailedViewCloseDelay(int close_delay);
- // Hides the detailed view for |item|.
- void HideDetailedView(SystemTrayItem* item);
+ // Hides the detailed view for |item|. If |animate| is false, disable
+ // the hiding animation for hiding |item|.
+ void HideDetailedView(SystemTrayItem* item, bool animate);
// Shows the notification view for |item|.
void ShowNotificationView(SystemTrayItem* item);

Powered by Google App Engine
This is Rietveld 408576698